@@ -14,11 +14,11 @@ import plotly.express as px
 
 
 class Surface:
-    def __init__(self, df):
+    def __init__(self, df, datestr, putcall, symbol):
         self.df = df.sort_values("delta")
-        self.day = df.datestr.iloc[1]
-        self.putCall = df.putCall.iloc[1]
-        self.symbol = df.currency.iloc[1]
+        self.day = datestr
+        self.putCall = putcall
+        self.symbol = symbol
         self.curves = []
         self.parse_curves()
 
